@@ -319,7 +319,6 @@ class TCPConnectionResource(resource.Resource):
         self.sendMsgQueue()
         if not self.open:
             self.open = True
-            self.packetId += 1
             self.cometTransport.sendPacket("open", self.packetId)
         self.cometTransport.flush()
 
@@ -354,8 +353,10 @@ class TCPConnectionResource(resource.Resource):
             self.logger.debug('close cometTransport %s' % repr(self.cometTransport))
             self.cometTransport.sendPacket('close', "", reason)
             self.cometTransport.flush()
-            self.cometTransport.close()
-            self.cometTransport = None
+            # previous line can cause cometTransport to close
+            if self.cometTransport:
+                self.cometTransport.close()
+                self.cometTransport = None
         self.connectionLost()
         # NOTE:
         # else:
@@ -372,7 +373,7 @@ class TCPConnectionResource(resource.Resource):
         ackId = min(ackId, self.packetId)
         if ackId <= self.lastAckId:
             return
-        for i in range(ackId - self.lastAckId - 1): # -1 as the OPEN packet need not be ack'ed
+        for i in range(ackId - self.lastAckId):
             self.unackQueue.pop(0)
         self.lastAckId = ackId
         
