@@ -39,7 +39,7 @@ Orbited.settings.hostname = document.domain
 Orbited.settings.port = (location.port.length > 0) ? location.port : 80
 Orbited.settings.protocol = 'http'
 Orbited.settings.log = false;
-Orbited.settings.streaming = false;
+Orbited.settings.streaming = true;
 Orbited.settings.HEARTBEAT_TIMEOUT = 6000
 Orbited.settings.POLL_INTERVAL = 2000
 Orbited.settings.pageLoggerHeight = '200px'
@@ -776,6 +776,7 @@ Orbited.TCPSocket = function() {
         sessionUrl.domain = Orbited.settings.hostname
         sessionUrl.port = Orbited.settings.port
         sessionUrl.protocol = Orbited.settings.protocol
+        sessionUrl.setQsParameter('nocache', Math.random())
         session.open(sessionUrl.render())
         session.onopen = sessionOnOpen;
         session.onread = sessionOnRead;
@@ -2009,7 +2010,10 @@ Orbited.CometTransports.SSE.opera9_5 = 0.8;
 
 
 /* This is an old implementation of the URL class. Jacob is cleaning it up
- * mcarter, 7-30-08
+ * -mcarter, 7-30-08
+ * 
+ * Jacob is actually throwing this away and rewriting from scratch
+ * -mcarter 11-14-08
  */
 Orbited.URL = function(_url) {
     var self = this;
@@ -2546,10 +2550,15 @@ try {
         var script = scripts[0]
         if (script.src.match('/static/Orbited\.js$')) {
             var url = new Orbited.URL(script.src)
-            Orbited.settings.hostname = url.domain;
-            Orbited.settings.port = url.port;
+            if (url.render().indexOf('http') != 0) {
+                var url = new Orbited.URL(window.location.toString());
+            }
+            Orbited.settings.hostname = url.domain
+            Orbited.settings.port = url.port
             break
         }
     }
-} catch(e) { }
+} catch(e) { 
+//    alert("Error! " + e.name + ": " + e.message);
+}
 })()
