@@ -158,7 +158,9 @@ LineProtocol = function(transport) {
         log.debug("close");
         transport.close();
     };
-
+    self.reset = function() {
+        transport.reset();
+    }
     //
     // callbacks for the events generated by this
     //
@@ -510,7 +512,9 @@ STOMPClient = function() {
         //     trigger an "onclose" event.
         self.sendFrame("DISCONNECT");
     };
-
+    self.reset = function() {
+        protocol.reset();
+    }
     self.send = function(message, destination, extraHeaders) {
         self.sendFrame("SEND", mergeObject({destination:destination}, extraHeaders), message);
     };
